@@ -1,7 +1,7 @@
 """DB-SIG compliant module for communicating with MS SQL servers"""
 
 __author__ = 'Mikhail Denisenko <denisenkom@gmail.com>'
-__version__ = '1.5.4'
+__version__ = '1.5.5'
 
 import logging
 import six
@@ -263,9 +263,9 @@ class _Connection(object):
         this case.
         """
         #logger.debug("MSSQLConnection.close()")
-        self._assert_open()
-        self._conn.close()
-        self._conn = None
+        if self._conn:
+            self._conn.close()
+            self._conn = None
 
     def select_db(self, dbname):
         """
@@ -426,7 +426,11 @@ class _Connection(object):
     def _close_cursor(self, cursor):
         if self._conn is not None and cursor._session is not None:
             if self._conn.mars_enabled:
-                cursor._session.close()
+                try:
+                    cursor._session.close()
+                except socket.error as e:
+                    if e.errno != errno.ECONNRESET:
+                        raise
             else:
                 if cursor is self._active_cursor:
                     self._active_cursor = None
